package jp.jasminesoft.wagby.tests.models.customer;

import javafx.scene.control.ComboBox;
import jp.jasminesoft.jfc.test.support.selenide.DateTextBox;
import jp.jasminesoft.jfc.test.support.selenide.ListBox;
import jp.jasminesoft.jfc.test.support.selenide.Postcode;
import jp.jasminesoft.jfc.test.support.selenide.WebConditionModel;
import jp.jasminesoft.jfc.test.support.selenide.WebModelitem;

/**
 * Customer モデルの検索条件部の情報を保持するクラス。
 *
 * @author JasmineSoft
 * @version $Revision$ $Date$
 */
public class CustomerCp extends WebConditionModel {

    /**
     * コンストラクタ。
     */
    public CustomerCp() {
        super("customer");
    }

    /**
     * customer/customerid
     * 検索画面では数値項目は範囲検索となる。
     * 範囲検索の下限項目(項目名末尾に "1jshparam" を付与)
     */
    public final WebModelitem<?> customerid1jshparam
            = new WebModelitem<>(this, "customerid1jshparam");

    /**
     * customer/customerid
     * 検索画面では数値項目は範囲検索となる。
     * 範囲検索の下限項目(項目名末尾に "2jshparam" を付与)
     */
    public final WebModelitem<?> customerid2jshparam
            = new WebModelitem<>(this, "customerid2jshparam");

    /** customer/name */
    public final WebModelitem<?> name
            = new WebModelitem<>(this, "name");

    /**
     * customer/customertype
     * 登録/更新画面では追記型リストボックスとして表現されるので、
     * {@link ComboBox} を用いるが、検索画面ではリストボックス
     * として表現されるので、{@link ListBox} を利用する。
     */
    public final ListBox customertype
            = new ListBox(this, "customertype");

    /** customer/title */
    public final WebModelitem<?> title
            = new WebModelitem<>(this, "title");

    /**
     * customer/zipcode */
    public final Postcode zipcode
            = new Postcode(this, "zipcode");

    /** customer/address */
    public final WebModelitem<?> address
            = new WebModelitem<>(this, "address");

    /**
     * customer/email
     * 検索画面では繰り返し項目扱いではないため、
     * {@link WebMultiModelitem} は使わない。
     */
    public final WebModelitem<?> email
            = new WebModelitem<>(this, "email");

    /** customer/tel */
    public final WebModelitem<?> tel
            = new WebModelitem<>(this, "tel");

    /**
     * customer/report/rdate
     * 検索画面ではコンテナ内項目は通常項目として
     * 扱われるため、{@link WebContainerModelitem} の定義は不要。
     */
    public final DateTextBox rdate1jshparam
            = new DateTextBox(this, "rdate1jshparam");

    /**
     * customer/report/rdate
     * 検索画面ではコンテナ内項目は通常項目として
     * 扱われるため、{@link WebContainerModelitem} の定義は不要。
     */
    public final DateTextBox rdate2jshparam
            = new DateTextBox(this, "rdate2jshparam");
}
