package jp.jasminesoft.wagby.tests.t001_Customer;

import static com.codeborne.selenide.Condition.*;
import static com.codeborne.selenide.Selenide.*;
import static jp.jasminesoft.jfc.test.support.selenide.Operations.*;
import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;

import jp.jasminesoft.wagby.tests.models.customer.CustomerCp;
import jp.jasminesoft.wagby.tests.models.customer.CustomerLp;
import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runners.MethodSorters;

/**
 * 2. Customer モデルの検索・一覧画面のテスト
 *
 * @author JasmineSoft
 * @version $Revision$ $Date$
 */
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class CustomerTest2 {

    /**
     * ログオン
     */
    @Test
    public void test00ログオン() {
        logon("admin", "wagby");
        pageTitle().shouldHave(exactText("メニュー"));
    }

    /**
     * 顧客情報検索へ遷移
     */
    @Test
    public void test01顧客情報検索へ遷移() {
        pageTitle().shouldHave(exactText("メニュー"));

        // メニューから顧客情報 検索画面へ遷移
        selectMenu("サービス", "顧客情報検索");
        pageTitle().shouldHave(exactText("顧客情報 検索"));
    }

    /**
     * 検索テスト
     */
    @Test
    public void test02検索テスト() {
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // WebConditionModel を継承した検索条件部を表すモデル。
        CustomerCp condition = new CustomerCp();

        // 以下、検索条件の入力。

        // 数値項目は検索画面では、下限部と上限部の2つの
        // 入力フィールドが用意されるので、対応する項目も
        // 2つ定義しておく。
        condition.customerid1jshparam.val("1");
        condition.customerid2jshparam.val("10000");

        // customertype 項目は登録/更新画面と検索画面では
        // 表示形式が異なるので注意。
        // 登録/更新画面では追記型リストボックスとして表現
        // されるので、ComboBox クラスを用いて定義されているが、
        // 検索画面ではリストボックスとして表現されるので、
        // ListBox クラスを項目クラスとして利用している。
        condition.customertype.val("地方公共団体");

        // 検索画面でも郵便番号と住所の同期が可能。
        condition.zipcode.val("901-2227").sync();

        // 住所項目: 郵便番号と同期後の値を確認。
        condition.address.shouldHave("沖縄県宜野湾市宇地泊");

        // 検索画面では繰り返し項目(WebMultiModelitem)ではなく
        // 通常項目(WebModelitem)として定義する。。
        condition.email.val("sales@jasminesoft.co.jp");

        // 日付項目も検索画面では、下限部と上限部に分かれている。
        // 検索画面でも DatePicker の利用が可能。
        condition.rdate1jshparam.datePicker()  // DetePicker を表示
                .nextMonth()          // 次の月へ
                .prevMonth()          // 前の月へ
                .nextYear()           // 次の年へ
                .prevYear()           // 前の年へ
                .selectDate(1);       // 1日を選択

        // 「検索の実行」ボタンをクリック。
        search();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 検索結果件数の確認。
        $(".display_resultcount").shouldHave(text(
                "検索条件に合致したデータは1件見つかりました。"));
    }

    /**
     * 一覧表示のテスト
     */
    @Test
    public void test03一覧表示のテスト() {
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 「一覧画面へ」ボタンをクリック。
        clickListPageButton();
        pageTitle().shouldHave(exactText("顧客情報 一覧"));
        // 検索結果件数の確認。
        $(".display_resultcount").shouldHave(text(
                "1件中、1件目から1件目を表示しています。"));

        // WebListModel を継承した一覧表示部を表すモデル。
        CustomerLp list = new CustomerLp();
        // 1行目のデータを取得
        CustomerLp record01 = list.get(1);
        // テストを繰り返し実行するとズレてくるため、
        // 自動採番主キーの確認は行わないほうがよい。
        //record01.customerid.shouldHave("1000");

        // 通常項目
        record01.name.shouldHave("ジャスミン太郎");

        // ラジオボタン
        record01.customertype.shouldHave("地方公共団体");
        record01.title.shouldHave("一般");
        // 郵便番号
        record01.zipcode.shouldHave("901-2227");
        record01.address.shouldHave("沖縄県宜野湾市宇地泊");
        // 繰返し項目
        record01.email.shouldHave(
                "taro@jasminesoft.co.jp", "sales@jasminesoft.co.jp");
        record01.tel.shouldHave("098-890-6036");

        // 2件目のデータがあれば、以下のように取得する。
        //CustomerLp record02 = list.get(2);

        // 「詳細」ボタンをクリック。
        record01.clickDetailButton();
        pageTitle().shouldHave(exactText("顧客情報 詳細表示"));

        // 「検索画面へ」ボタンをクリック
        clickSearchPageButton();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 1行目の「更新」ボタンをクリック。
        //record01.clickEditButton();
        //pageTitle().shouldHave(exactText("顧客情報 更新"));

        // 1行目の「コピー」ボタンをクリック。
        //record01.clickCopyButton();
        //pageTitle().shouldHave(exactText("顧客情報 コピー登録"));
    }

    /**
     * 検索条件リセットテスト
     */
    @Test
    public void test04検索条件リセットテスト() {
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 「リセット」ボタンをクリック。
        resetSearch();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // メッセージの確認。
        $(".display_resultcount").shouldHave(exactText(
                "検索条件を入力してください。"));
    }

    /**
     * ログオフ
     */
    @Test
    public void test99ログオフ() {
        logoff();
    }
}
